==> gitlab-8.14.4-1-armv6h.pkg.tar.xz: usr/share/webapps/gitlab/doc/workflow/README.md <==
# Workflow

- [Automatic issue closing](../user/project/issues/automatic_issue_closing.md)
- [Change your time zone](timezone.md)
- [Cycle Analytics](../user/project/cycle_analytics.md)
- [Description templates](../user/project/description_templates.md)
- [Feature branch workflow](workflow.md)
- [GitLab Flow](gitlab_flow.md)
- [Groups](groups.md)
- [Issue Board](../user/project/issue_board.md)
- [Keyboard shortcuts](shortcuts.md)
- [File finder](file_finder.md)
- [Labels](../user/project/labels.md)
- [Notification emails](notifications.md)
- [Project Features](project_features.md)
- [Project forking workflow](forking_workflow.md)
- [Project users](add-user/add-user.md)
- [Protected branches](../user/project/protected_branches.md)
- [Slash commands](../user/project/slash_commands.md)
- [Sharing a project with a group](share_with_group.md)
- [Share projects with other groups](share_projects_with_other_groups.md)
- [Web Editor](../user/project/repository/web_editor.md)
- [Releases](releases.md)
- [Milestones](milestones.md)
- [Merge Requests](../user/project/merge_requests.md)
  - [Authorization for merge requests](../user/project/merge_requests/authorization_for_merge_requests.md)
  - [Cherry-pick changes](../user/project/merge_requests/cherry_pick_changes.md)
  - [Merge when build succeeds](../user/project/merge_requests/merge_when_build_succeeds.md)
  - [Resolve discussion comments in merge requests reviews](../user/project/merge_requests/merge_request_discussion_resolution.md)
  - [Resolve merge conflicts in the UI](../user/project/merge_requests/resolve_conflicts.md)
  - [Revert changes in the UI](../user/project/merge_requests/revert_changes.md)
  - [Merge requests versions](../user/project/merge_requests/versions.md)
  - ["Work In Progress" merge requests](../user/project/merge_requests/work_in_progress_merge_requests.md)
- [Manage large binaries with Git LFS](lfs/manage_large_binaries_with_git_lfs.md)
- [Importing from SVN, GitHub, BitBucket, etc](importing/README.md)
- [Todos](todos.md)

==> gitlab-8.15.1-1-armv6h.pkg.tar.xz: usr/share/webapps/gitlab/doc/workflow/README.md <==
# Workflow

- [Automatic issue closing](../user/project/issues/automatic_issue_closing.md)
- [Change your time zone](timezone.md)
- [Cycle Analytics](../user/project/cycle_analytics.md)
- [Description templates](../user/project/description_templates.md)
- [Feature branch workflow](workflow.md)
- [GitLab Flow](gitlab_flow.md)
- [Groups](groups.md)
- [Issue Board](../user/project/issue_board.md)
- [Keyboard shortcuts](shortcuts.md)
- [File finder](file_finder.md)
- [Labels](../user/project/labels.md)
- [Notification emails](notifications.md)
- [Project Features](project_features.md)
- [Project forking workflow](forking_workflow.md)
- [Project users](add-user/add-user.md)
- [Protected branches](../user/project/protected_branches.md)
- [Slash commands](../user/project/slash_commands.md)
- [Sharing a project with a group](share_with_group.md)
- [Share projects with other groups](share_projects_with_other_groups.md)
- [Web Editor](../user/project/repository/web_editor.md)
- [Releases](releases.md)
- [Milestones](milestones.md)
- [Merge Requests](../user/project/merge_requests.md)
  - [Authorization for merge requests](../user/project/merge_requests/authorization_for_merge_requests.md)
  - [Cherry-pick changes](../user/project/merge_requests/cherry_pick_changes.md)
  - [Merge when pipeline succeeds](../user/project/merge_requests/merge_when_pipeline_succeeds.md)
  - [Resolve discussion comments in merge requests reviews](../user/project/merge_requests/merge_request_discussion_resolution.md)
  - [Resolve merge conflicts in the UI](../user/project/merge_requests/resolve_conflicts.md)
  - [Revert changes in the UI](../user/project/merge_requests/revert_changes.md)
  - [Merge requests versions](../user/project/merge_requests/versions.md)
  - ["Work In Progress" merge requests](../user/project/merge_requests/work_in_progress_merge_requests.md)
- [Manage large binaries with Git LFS](lfs/manage_large_binaries_with_git_lfs.md)
- [Importing from SVN, GitHub, Bitbucket, etc](importing/README.md)
- [Todos](todos.md)
